@@ -1,14 +1,14 @@
-# -*- encoding:ascii -*-
+# -*- encoding:utf-8 -*-
 from mako import runtime, filters, cache
 UNDEFINED = runtime.UNDEFINED
 __M_dict_builtin = dict
 __M_locals_builtin = locals
 _magic_number = 8
-_modified_time = 1334581848.684365
+_modified_time = 1336003353.266474
 _enable_loop = True
 _template_filename = '/mnt/md0/MyWork/MyProjects/PyCK/pyck/forms/templates/form_as_p.mako'
 _template_uri = 'form_as_p.mako'
-_source_encoding = 'ascii'
+_source_encoding = 'utf-8'
 _exports = []
 
 
@@ -20,23 +20,23 @@ def render_body(context,**pageargs):
         labels_position = context.get('labels_position', UNDEFINED)
         form = context.get('form', UNDEFINED)
         __M_writer = context.writer()
-        # SOURCE LINE 1
+        # SOURCE LINE 2
         if form._use_csrf_protection:
-            # SOURCE LINE 2
+            # SOURCE LINE 3
             __M_writer(u'<input type="hidden" name="csrf_token" value="')
             __M_writer(unicode(form._csrf_token))
             __M_writer(u'" />\n')
             pass
-        # SOURCE LINE 4
+        # SOURCE LINE 5
         if '_csrf' in form.errors:
-            # SOURCE LINE 5
+            # SOURCE LINE 6
             __M_writer(u'<div class="errors">')
             __M_writer(unicode(form.errors['_csrf'][0]))
             __M_writer(u'</div><br />\n')
             pass
-        # SOURCE LINE 7
+        # SOURCE LINE 8
         for field in form:
-            # SOURCE LINE 8
+            # SOURCE LINE 9
 
             field_errors = ''
             if field.errors:
@@ -49,62 +49,68 @@ def render_body(context,**pageargs):
             
             __M_locals_builtin_stored = __M_locals_builtin()
             __M_locals.update(__M_dict_builtin([(__M_key, __M_locals_builtin_stored[__M_key]) for __M_key in ['field_errors','e'] if __M_key in __M_locals_builtin_stored]))
-            # SOURCE LINE 16
+            # SOURCE LINE 17
             __M_writer(u'\n<p>\n')
-            # SOURCE LINE 18
+            # SOURCE LINE 19
             if 'top' == labels_position:
-                # SOURCE LINE 19
+                # SOURCE LINE 20
                 __M_writer(unicode(field.label))
                 __M_writer(u'<br /> ')
                 pass
-            # SOURCE LINE 22
+            # SOURCE LINE 23
             if field_errors and 'top'==errors_position:
-                # SOURCE LINE 23
+                # SOURCE LINE 24
                 __M_writer(unicode(field_errors))
                 __M_writer(u'<br /> ')
                 pass
-            # SOURCE LINE 26
+            # SOURCE LINE 27
             if 'left' == labels_position:
-                # SOURCE LINE 27
+                # SOURCE LINE 28
                 __M_writer(unicode(field.label))
                 __M_writer(u' ')
                 pass
-            # SOURCE LINE 30
+            # SOURCE LINE 31
             if field_errors and 'left'==errors_position:
-                # SOURCE LINE 31
+                # SOURCE LINE 32
                 __M_writer(unicode(field_errors))
                 __M_writer(u' ')
                 pass
-            # SOURCE LINE 34
-            __M_writer(unicode(field))
-            __M_writer(u' ')
             # SOURCE LINE 35
+
+            context.write(field().encode("utf-8", errors="ignore"))
+            
+            
+            __M_locals_builtin_stored = __M_locals_builtin()
+            __M_locals.update(__M_dict_builtin([(__M_key, __M_locals_builtin_stored[__M_key]) for __M_key in [] if __M_key in __M_locals_builtin_stored]))
+            # SOURCE LINE 37
+            __M_writer(u' ')
+            # SOURCE LINE 38
             if 'bottom' == labels_position:
-                # SOURCE LINE 36
+                # SOURCE LINE 39
                 __M_writer(u'<br />')
                 __M_writer(unicode(field.label))
                 __M_writer(u' ')
                 pass
-            # SOURCE LINE 39
+            # SOURCE LINE 42
             if field_errors and 'bottom'==errors_position:
-                # SOURCE LINE 40
+                # SOURCE LINE 43
                 __M_writer(u'<br />')
                 __M_writer(unicode(field_errors))
                 __M_writer(u' ')
                 pass
-            # SOURCE LINE 43
+            # SOURCE LINE 46
             if 'right' == labels_position:
-                # SOURCE LINE 44
+                # SOURCE LINE 47
                 __M_writer(unicode(field.label))
                 __M_writer(u' ')
                 pass
-            # SOURCE LINE 47
-            if field_errors and 'right'==errors_position:
-                # SOURCE LINE 48
-                __M_writer(unicode(field_errors))
-                __M_writer(u' ')
-                pass
             # SOURCE LINE 50
+            if field_errors and 'right'==errors_position:
+                # SOURCE LINE 51
+                __M_writer(unicode(field_errors))
+                __M_writer(u' ')
+                pass
+            # SOURCE LINE 53
             __M_writer(u'</p>\n')
             pass
         return ''
